@@ -30,21 +30,22 @@ class CompressionAlgo(Enum):
 
 
 if TYPE_CHECKING:
+    from typing import (
+        AbstractSet,
+        Any,
+        Callable,
+        Dict,
+        List,
+        Optional,
+        Sequence,
+        Tuple,
+        Type,
+        Union,
+    )
+
+    from typing_extensions import Literal, TypedDict
+
     import sentry_sdk
-
-    from typing import Optional
-    from typing import Callable
-    from typing import Union
-    from typing import List
-    from typing import Type
-    from typing import Dict
-    from typing import Any
-    from typing import Sequence
-    from typing import Tuple
-    from typing import AbstractSet
-    from typing_extensions import Literal
-    from typing_extensions import TypedDict
-
     from sentry_sdk._types import (
         BreadcrumbProcessor,
         ContinuousProfilerMode,
@@ -104,8 +105,7 @@ class SPANTEMPLATE(str, Enum):
     AI_TOOL = "ai_tool"
     AI_CHAT = "ai_chat"
 
-    def __str__(self):
-        # type: () -> str
+    def __str__(self) -> str:
         return self.value
 
 
@@ -936,6 +936,7 @@ class OP:
     QUEUE_SUBMIT_RAY = "queue.submit.ray"
     QUEUE_TASK_RAY = "queue.task.ray"
     QUEUE_TASK_DRAMATIQ = "queue.task.dramatiq"
+    QUEUE_SUBMIT_DJANGO = "queue.submit.django"
     SUBPROCESS = "subprocess"
     SUBPROCESS_WAIT = "subprocess.wait"
     SUBPROCESS_COMMUNICATE = "subprocess.communicate"
@@ -953,80 +954,79 @@ class OP:
 class ClientConstructor:
     def __init__(
         self,
-        dsn=None,  # type: Optional[str]
+        dsn: "Optional[str]" = None,
         *,
-        max_breadcrumbs=DEFAULT_MAX_BREADCRUMBS,  # type: int
-        release=None,  # type: Optional[str]
-        environment=None,  # type: Optional[str]
-        server_name=None,  # type: Optional[str]
-        shutdown_timeout=2,  # type: float
-        integrations=[],  # type: Sequence[sentry_sdk.integrations.Integration]  # noqa: B006
-        in_app_include=[],  # type: List[str]  # noqa: B006
-        in_app_exclude=[],  # type: List[str]  # noqa: B006
-        default_integrations=True,  # type: bool
-        dist=None,  # type: Optional[str]
-        transport=None,  # type: Optional[Union[sentry_sdk.transport.Transport, Type[sentry_sdk.transport.Transport], Callable[[Event], None]]]
-        transport_queue_size=DEFAULT_QUEUE_SIZE,  # type: int
-        sample_rate=1.0,  # type: float
-        send_default_pii=None,  # type: Optional[bool]
-        http_proxy=None,  # type: Optional[str]
-        https_proxy=None,  # type: Optional[str]
-        ignore_errors=[],  # type: Sequence[Union[type, str]]  # noqa: B006
-        max_request_body_size="medium",  # type: str
-        socket_options=None,  # type: Optional[List[Tuple[int, int, int | bytes]]]
-        keep_alive=None,  # type: Optional[bool]
-        before_send=None,  # type: Optional[EventProcessor]
-        before_breadcrumb=None,  # type: Optional[BreadcrumbProcessor]
-        debug=None,  # type: Optional[bool]
-        attach_stacktrace=False,  # type: bool
-        ca_certs=None,  # type: Optional[str]
-        propagate_traces=True,  # type: bool
-        traces_sample_rate=None,  # type: Optional[float]
-        traces_sampler=None,  # type: Optional[TracesSampler]
-        profiles_sample_rate=None,  # type: Optional[float]
-        profiles_sampler=None,  # type: Optional[TracesSampler]
-        profiler_mode=None,  # type: Optional[ProfilerMode]
-        profile_lifecycle="manual",  # type: Literal["manual", "trace"]
-        profile_session_sample_rate=None,  # type: Optional[float]
-        auto_enabling_integrations=True,  # type: bool
-        disabled_integrations=None,  # type: Optional[Sequence[sentry_sdk.integrations.Integration]]
-        auto_session_tracking=True,  # type: bool
-        send_client_reports=True,  # type: bool
-        _experiments={},  # type: Experiments  # noqa: B006
-        proxy_headers=None,  # type: Optional[Dict[str, str]]
-        instrumenter=INSTRUMENTER.SENTRY,  # type: Optional[str]
-        before_send_transaction=None,  # type: Optional[TransactionProcessor]
-        project_root=None,  # type: Optional[str]
-        enable_tracing=None,  # type: Optional[bool]
-        include_local_variables=True,  # type: Optional[bool]
-        include_source_context=True,  # type: Optional[bool]
-        trace_propagation_targets=[  # noqa: B006
+        max_breadcrumbs: int = DEFAULT_MAX_BREADCRUMBS,
+        release: "Optional[str]" = None,
+        environment: "Optional[str]" = None,
+        server_name: "Optional[str]" = None,
+        shutdown_timeout: float = 2,
+        integrations: "Sequence[sentry_sdk.integrations.Integration]" = [],  # noqa: B006
+        in_app_include: "List[str]" = [],  # noqa: B006
+        in_app_exclude: "List[str]" = [],  # noqa: B006
+        default_integrations: bool = True,
+        dist: "Optional[str]" = None,
+        transport: "Optional[Union[sentry_sdk.transport.Transport, Type[sentry_sdk.transport.Transport], Callable[[Event], None]]]" = None,
+        transport_queue_size: int = DEFAULT_QUEUE_SIZE,
+        sample_rate: float = 1.0,
+        send_default_pii: "Optional[bool]" = None,
+        http_proxy: "Optional[str]" = None,
+        https_proxy: "Optional[str]" = None,
+        ignore_errors: "Sequence[Union[type, str]]" = [],  # noqa: B006
+        max_request_body_size: str = "medium",
+        socket_options: "Optional[List[Tuple[int, int, int | bytes]]]" = None,
+        keep_alive: "Optional[bool]" = None,
+        before_send: "Optional[EventProcessor]" = None,
+        before_breadcrumb: "Optional[BreadcrumbProcessor]" = None,
+        debug: "Optional[bool]" = None,
+        attach_stacktrace: bool = False,
+        ca_certs: "Optional[str]" = None,
+        propagate_traces: bool = True,
+        traces_sample_rate: "Optional[float]" = None,
+        traces_sampler: "Optional[TracesSampler]" = None,
+        profiles_sample_rate: "Optional[float]" = None,
+        profiles_sampler: "Optional[TracesSampler]" = None,
+        profiler_mode: "Optional[ProfilerMode]" = None,
+        profile_lifecycle: 'Literal["manual", "trace"]' = "manual",
+        profile_session_sample_rate: "Optional[float]" = None,
+        auto_enabling_integrations: bool = True,
+        disabled_integrations: "Optional[Sequence[sentry_sdk.integrations.Integration]]" = None,
+        auto_session_tracking: bool = True,
+        send_client_reports: bool = True,
+        _experiments: "Experiments" = {},  # noqa: B006
+        proxy_headers: "Optional[Dict[str, str]]" = None,
+        instrumenter: "Optional[str]" = INSTRUMENTER.SENTRY,
+        before_send_transaction: "Optional[TransactionProcessor]" = None,
+        project_root: "Optional[str]" = None,
+        enable_tracing: "Optional[bool]" = None,
+        include_local_variables: "Optional[bool]" = True,
+        include_source_context: "Optional[bool]" = True,
+        trace_propagation_targets: "Optional[Sequence[str]]" = [  # noqa: B006
             MATCH_ALL
-        ],  # type: Optional[Sequence[str]]
-        functions_to_trace=[],  # type: Sequence[Dict[str, str]]  # noqa: B006
-        event_scrubber=None,  # type: Optional[sentry_sdk.scrubber.EventScrubber]
-        max_value_length=DEFAULT_MAX_VALUE_LENGTH,  # type: int
-        enable_backpressure_handling=True,  # type: bool
-        error_sampler=None,  # type: Optional[Callable[[Event, Hint], Union[float, bool]]]
-        enable_db_query_source=True,  # type: bool
-        db_query_source_threshold_ms=100,  # type: int
-        enable_http_request_source=True,  # type: bool
-        http_request_source_threshold_ms=100,  # type: int
-        spotlight=None,  # type: Optional[Union[bool, str]]
-        cert_file=None,  # type: Optional[str]
-        key_file=None,  # type: Optional[str]
-        custom_repr=None,  # type: Optional[Callable[..., Optional[str]]]
-        add_full_stack=DEFAULT_ADD_FULL_STACK,  # type: bool
-        max_stack_frames=DEFAULT_MAX_STACK_FRAMES,  # type: Optional[int]
-        enable_logs=False,  # type: bool
-        before_send_log=None,  # type: Optional[Callable[[Log, Hint], Optional[Log]]]
-        trace_ignore_status_codes=frozenset(),  # type: AbstractSet[int]
-        enable_metrics=True,  # type: bool
-        before_send_metric=None,  # type: Optional[Callable[[Metric, Hint], Optional[Metric]]]
-        org_id=None,  # type: Optional[str]
-        strict_trace_continuation=False,  # type: bool
-    ):
-        # type: (...) -> None
+        ],
+        functions_to_trace: "Sequence[Dict[str, str]]" = [],  # noqa: B006
+        event_scrubber: "Optional[sentry_sdk.scrubber.EventScrubber]" = None,
+        max_value_length: int = DEFAULT_MAX_VALUE_LENGTH,
+        enable_backpressure_handling: bool = True,
+        error_sampler: "Optional[Callable[[Event, Hint], Union[float, bool]]]" = None,
+        enable_db_query_source: bool = True,
+        db_query_source_threshold_ms: int = 100,
+        enable_http_request_source: bool = True,
+        http_request_source_threshold_ms: int = 100,
+        spotlight: "Optional[Union[bool, str]]" = None,
+        cert_file: "Optional[str]" = None,
+        key_file: "Optional[str]" = None,
+        custom_repr: "Optional[Callable[..., Optional[str]]]" = None,
+        add_full_stack: bool = DEFAULT_ADD_FULL_STACK,
+        max_stack_frames: "Optional[int]" = DEFAULT_MAX_STACK_FRAMES,
+        enable_logs: bool = False,
+        before_send_log: "Optional[Callable[[Log, Hint], Optional[Log]]]" = None,
+        trace_ignore_status_codes: "AbstractSet[int]" = frozenset(),
+        enable_metrics: bool = True,
+        before_send_metric: "Optional[Callable[[Metric, Hint], Optional[Metric]]]" = None,
+        org_id: "Optional[str]" = None,
+        strict_trace_continuation: bool = False,
+    ) -> None:
         """Initialize the Sentry SDK with the given parameters. All parameters described here can be used in a call to `sentry_sdk.init()`.
 
         :param dsn: The DSN tells the SDK where to send the events.
@@ -1446,8 +1446,7 @@ class ClientConstructor:
         pass
 
 
-def _get_default_options():
-    # type: () -> dict[str, Any]
+def _get_default_options() -> "dict[str, Any]":
     import inspect
 
     a = inspect.getfullargspec(ClientConstructor.__init__)
@@ -1466,4 +1465,4 @@ DEFAULT_OPTIONS = _get_default_options()
 del _get_default_options
 
 
-VERSION = "2.47.0"
+VERSION = "2.49.0"
