@@ -9,9 +9,7 @@ if TYPE_CHECKING:
     import agents
 
 
-def agent_workflow_span(agent):
-    # type: (agents.Agent) -> sentry_sdk.tracing.Span
-
+def agent_workflow_span(agent: "agents.Agent") -> "sentry_sdk.tracing.Span":
     # Create a transaction or a span if an transaction is already active
     span = get_start_span_function()(
         name=f"{agent.name} workflow",
