@@ -39,16 +39,16 @@ class RqIntegration(Integration):
     origin = f"auto.queue.{identifier}"
 
     @staticmethod
-    def setup_once():
-        # type: () -> None
+    def setup_once() -> None:
         version = parse_version(RQ_VERSION)
         _check_minimum_version(RqIntegration, version)
 
         old_perform_job = Worker.perform_job
 
         @ensure_integration_enabled(RqIntegration, old_perform_job)
-        def sentry_patched_perform_job(self, job, *args, **kwargs):
-            # type: (Any, Job, *Queue, **Any) -> bool
+        def sentry_patched_perform_job(
+            self: "Any", job: "Job", *args: "Queue", **kwargs: "Any"
+        ) -> bool:
             with sentry_sdk.new_scope() as scope:
                 scope.clear_breadcrumbs()
                 scope.add_event_processor(_make_event_processor(weakref.ref(job)))
@@ -82,8 +82,9 @@ class RqIntegration(Integration):
 
         old_handle_exception = Worker.handle_exception
 
-        def sentry_patched_handle_exception(self, job, *exc_info, **kwargs):
-            # type: (Worker, Any, *Any, **Any) -> Any
+        def sentry_patched_handle_exception(
+            self: "Worker", job: "Any", *exc_info: "Any", **kwargs: "Any"
+        ) -> "Any":
             retry = (
                 hasattr(job, "retries_left")
                 and job.retries_left
@@ -100,8 +101,9 @@ class RqIntegration(Integration):
         old_enqueue_job = Queue.enqueue_job
 
         @ensure_integration_enabled(RqIntegration, old_enqueue_job)
-        def sentry_patched_enqueue_job(self, job, **kwargs):
-            # type: (Queue, Any, **Any) -> Any
+        def sentry_patched_enqueue_job(
+            self: "Queue", job: "Any", **kwargs: "Any"
+        ) -> "Any":
             scope = sentry_sdk.get_current_scope()
             if scope.span is not None:
                 job.meta["_sentry_trace_headers"] = dict(
@@ -115,10 +117,8 @@ class RqIntegration(Integration):
         ignore_logger("rq.worker")
 
 
-def _make_event_processor(weak_job):
-    # type: (Callable[[], Job]) -> EventProcessor
-    def event_processor(event, hint):
-        # type: (Event, dict[str, Any]) -> Event
+def _make_event_processor(weak_job: "Callable[[], Job]") -> "EventProcessor":
+    def event_processor(event: "Event", hint: "dict[str, Any]") -> "Event":
         job = weak_job()
         if job is not None:
             with capture_internal_exceptions():
@@ -148,8 +148,7 @@ def _make_event_processor(weak_job):
     return event_processor
 
 
-def _capture_exception(exc_info, **kwargs):
-    # type: (ExcInfo, **Any) -> None
+def _capture_exception(exc_info: "ExcInfo", **kwargs: "Any") -> None:
     client = sentry_sdk.get_client()
 
     event, hint = event_from_exception(
