@@ -1,10 +1,14 @@
 # NOTE: this is the logger sentry exposes to users, not some generic logger.
 import functools
 import time
-from typing import Any
+from typing import Any, TYPE_CHECKING
+
+import sentry_sdk
+from sentry_sdk.utils import format_attribute, safe_repr, capture_internal_exceptions
+
+if TYPE_CHECKING:
+    from sentry_sdk._types import Attributes, Log
 
-from sentry_sdk import get_client
-from sentry_sdk.utils import safe_repr, capture_internal_exceptions
 
 OTEL_RANGES = [
     # ((severity level range), severity text)
@@ -21,52 +25,42 @@ OTEL_RANGES = [
 class _dict_default_key(dict):  # type: ignore[type-arg]
     """dict that returns the key if missing."""
 
-    def __missing__(self, key):
-        # type: (str) -> str
+    def __missing__(self, key: str) -> str:
         return "{" + key + "}"
 
 
-def _capture_log(severity_text, severity_number, template, **kwargs):
-    # type: (str, int, str, **Any) -> None
-    client = get_client()
-
+def _capture_log(
+    severity_text: str, severity_number: int, template: str, **kwargs: "Any"
+) -> None:
     body = template
-    attrs = {}  # type: dict[str, str | bool | float | int]
+
+    attributes: "Attributes" = {}
+
     if "attributes" in kwargs:
-        attrs.update(kwargs.pop("attributes"))
+        provided_attributes = kwargs.pop("attributes") or {}
+        for attribute, value in provided_attributes.items():
+            attributes[attribute] = format_attribute(value)
+
     for k, v in kwargs.items():
-        attrs[f"sentry.message.parameter.{k}"] = v
+        attributes[f"sentry.message.parameter.{k}"] = format_attribute(v)
+
     if kwargs:
         # only attach template if there are parameters
-        attrs["sentry.message.template"] = template
+        attributes["sentry.message.template"] = format_attribute(template)
 
         with capture_internal_exceptions():
             body = template.format_map(_dict_default_key(kwargs))
 
-    attrs = {
-        k: (
-            v
-            if (
-                isinstance(v, str)
-                or isinstance(v, int)
-                or isinstance(v, bool)
-                or isinstance(v, float)
-            )
-            else safe_repr(v)
-        )
-        for (k, v) in attrs.items()
-    }
-
-    # noinspection PyProtectedMember
-    client._capture_log(
+    sentry_sdk.get_current_scope()._capture_log(
         {
             "severity_text": severity_text,
             "severity_number": severity_number,
-            "attributes": attrs,
+            "attributes": attributes,
             "body": body,
             "time_unix_nano": time.time_ns(),
             "trace_id": None,
-        },
+            "span_id": None,
+        }
     )
 
 
@@ -78,8 +72,7 @@ error = functools.partial(_capture_log, "error", 17)
 fatal = functools.partial(_capture_log, "fatal", 21)
 
 
-def _otel_severity_text(otel_severity_number):
-    # type: (int) -> str
+def _otel_severity_text(otel_severity_number: int) -> str:
     for (lower, upper), severity in OTEL_RANGES:
         if lower <= otel_severity_number <= upper:
             return severity
@@ -87,8 +80,7 @@ def _otel_severity_text(otel_severity_number):
     return "default"
 
 
-def _log_level_to_otel(level, mapping):
-    # type: (int, dict[Any, int]) -> tuple[int, str]
+def _log_level_to_otel(level: int, mapping: "dict[Any, int]") -> "tuple[int, str]":
     for py_level, otel_severity_number in sorted(mapping.items(), reverse=True):
         if level >= py_level:
             return otel_severity_number, _otel_severity_text(otel_severity_number)
